@@ -2,10 +2,6 @@
 # Copyright 2013 Red Hat, Inc
 # Copyright Ericsson AB 2014. All rights reserved
 #
-# Authors: Angus Salkeld <asalkeld@redhat.com>
-#          Balazs Gibizer <balazs.gibizer@ericsson.com>
-#          Ildiko Vancsa <ildiko.vancsa@ericsson.com>
-#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -266,10 +262,14 @@ def do_sample_create(cc, args={}):
                 'but if supplied must be string, integer, float, or boolean.')
 @utils.arg('-l', '--limit', metavar='<NUMBER>',
            help='Maximum number of meters to return. %s' % DEFAULT_API_LIMIT)
+@utils.arg('--unique', dest='unique',
+           metavar='{True|False}',
+           type=lambda v: strutils.bool_from_string(v, True),
+           help='Retrieves unique list of meters.')
 def do_meter_list(cc, args={}):
     """List the user's meters."""
     meters = cc.meters.list(q=options.cli_to_array(args.query),
-                            limit=args.limit)
+                            limit=args.limit, unique=args.unique)
     field_labels = ['Name', 'Type', 'Unit', 'Resource ID', 'User ID',
                     'Project ID']
     fields = ['name', 'type', 'unit', 'resource_id', 'user_id',
@@ -499,7 +499,6 @@ def common_alarm_arguments(create=False):
                          '[timezone=<IANA Timezone>]]'))
         @utils.arg('--repeat-actions', dest='repeat_actions',
                    metavar='{True|False}', type=strutils.bool_from_string,
-                   default=False,
                    help=('True if actions should be repeatedly notified '
                          'while alarm remains in target state.'))
         @functools.wraps(func)
@@ -519,6 +518,7 @@ def common_alarm_gnocchi_arguments(rule_namespace, create=False):
                    help='Number of periods to evaluate over.')
         @utils.arg('--aggregation-method', metavar='<AGGREATION>',
                    dest=rule_namespace + '/aggregation_method',
+                   required=create,
                    help=('Aggregation method to use, one of: ' +
                          str(GNOCCHI_AGGREGATION) + '.'))
         @utils.arg('--comparison-operator', metavar='<OPERATOR>',
